import { type InjectionKey, type Ref, type VNodeChild, type ComputedRef } from 'vue';
import type { MenuDataItem, FormatMessage, WithFalse } from './typings';
import type { PureSettings } from './defaultSettings';
export interface Route {
    path: string;
    breadcrumbName: string;
    children?: Omit<Route, 'children'>[];
}
export interface BreadcrumbProps {
    prefixCls?: string;
    routes?: Route[];
    params?: any;
    separator?: VNodeChild;
    itemRender?: (opts: {
        route: Route;
        params: any;
        routes: Array<Route>;
        paths: Array<string>;
    }) => VNodeChild;
}
export declare type BreadcrumbListReturn = Pick<BreadcrumbProps, Extract<keyof BreadcrumbProps, 'routes' | 'itemRender'>>;
export interface MenuState {
    selectedKeys: string[];
    openKeys: string[];
}
export interface RouteContextProps extends Partial<PureSettings>, MenuState {
    menuData: MenuDataItem[];
    flatMenuData?: MenuDataItem[];
    getPrefixCls?: (suffixCls?: string, customizePrefixCls?: string) => string;
    locale?: WithFalse<FormatMessage>;
    breadcrumb?: BreadcrumbListReturn | ComputedRef<BreadcrumbListReturn>;
    isMobile?: boolean;
    prefixCls?: string;
    collapsed?: boolean;
    hasSideMenu?: boolean;
    hasHeader?: boolean;
    siderWidth?: number;
    headerHeight?: number;
    hasFooterToolbar?: boolean;
    hasFooter?: boolean;
    hasSide?: boolean;
    setHasFooterToolbar?: (bool: boolean) => void;
    [key: string]: any;
}
export declare const defaultPrefixCls = "ant-pro";
export declare const getPrefixCls: (suffixCls?: string | undefined, customizePrefixCls?: string | undefined) => string;
export declare const defaultRouteContext: {
    getPrefixCls: (suffixCls?: string | undefined, customizePrefixCls?: string | undefined) => string;
    locale: (t: string) => string;
    contentWidth: string;
    hasFooterToolbar: boolean;
};
export declare const routeContextInjectKey: InjectionKey<RouteContextProps>;
export declare const createRouteContext: () => import("./hooks/context").CreateContext<RouteContextProps>;
export declare const provideRouteContext: (value: RouteContextProps | Ref<RouteContextProps>) => void;
export declare const useRouteContext: () => Required<RouteContextProps>;
declare const _default: {
    Provider: import("./hooks/context").CreateContext<RouteContextProps>;
};
export default _default;
